summaryrefslogtreecommitdiffstats
path: root/karm/karmstorage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'karm/karmstorage.cpp')
-rw-r--r--karm/karmstorage.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/karm/karmstorage.cpp b/karm/karmstorage.cpp
index 1231113b..1e4f92a1 100644
--- a/karm/karmstorage.cpp
+++ b/karm/karmstorage.cpp
@@ -156,7 +156,7 @@ TQString KarmStorage::load (TaskView* view, const Preferences* preferences, TQSt
TQDict< Task > map;
// Build dictionary to look up Task object from Todo uid. Each task is a
// TQListViewItem, and is initially added with the view as the tqparent.
todoList = _calendar->rawTodos();
kdDebug(5970) << "KarmStorage::load "
<< "rawTodo count (includes completed todos) ="
@@ -186,7 +186,7 @@ TQString KarmStorage::load (TaskView* view, const Preferences* preferences, TQSt
task->setPixmapProgress();
}
// Load each task under it's tqparent task.
for( todo = todoList.begin(); todo != todoList.end(); ++todo )
{
Task* task = map.find( (*todo)->uid() );
@@ -198,7 +198,7 @@ TQString KarmStorage::load (TaskView* view, const Preferences* preferences, TQSt
// Complete the loading but return a message
if ( !newParent )
- err = i18n("Error loading \"%1\": could not find tqparent (uid=%2)")
+ err = i18n("Error loading \"%1\": could not find parent (uid=%2)")
.tqarg(task->name())
.tqarg((*todo)->relatedToUid());
@@ -245,7 +245,7 @@ TQString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
// 1. insert tasks form rc into taskview
// 1.1. Build dictionary to look up Task object from Todo uid. Each task is a
// TQListViewItem, and is initially added with the view as the tqparent.
todoList = rc->rawTodos();
for( todo = todoList.begin(); todo != todoList.end(); ++todo )
{
@@ -255,7 +255,7 @@ TQString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
task->setPixmapProgress();
}
// 1.1. Load each task under it's tqparent task.
for( todo = todoList.begin(); todo != todoList.end(); ++todo )
{
Task* task = map.find( (*todo)->uid() );
@@ -267,7 +267,7 @@ TQString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
// Complete the loading but return a message
if ( !newParent )
- err = i18n("Error loading \"%1\": could not find tqparent (uid=%2)")
+ err = i18n("Error loading \"%1\": could not find parent (uid=%2)")
.tqarg(task->name())
.tqarg((*todo)->relatedToUid());
@@ -439,17 +439,17 @@ TQString KarmStorage::loadFromFlatFile(TaskView* taskview,
task->setUid(addTask(task, 0));
}
else {
- Task *tqparent = stack.top();
+ Task *parent = stack.top();
kdDebug(5970) << "KarmStorage::loadFromFlatFile - task: " << name
- << " min: " << minutes << " tqparent" << tqparent->name() << "\n";
- task = new Task(name, minutes, 0, desktopList, tqparent);
+ << " min: " << minutes << " parent" << parent->name() << "\n";
+ task = new Task(name, minutes, 0, desktopList, parent);
- task->setUid(addTask(task, tqparent));
+ task->setUid(addTask(task, parent));
// Legacy File Format (!):
- tqparent->changeTimes(0, -minutes);
+ parent->changeTimes(0, -minutes);
taskview->setRootIsDecorated(true);
- tqparent->setOpen(true);
+ parent->setOpen(true);
}
if (!task->uid().isNull())
stack.push(task);
@@ -556,12 +556,12 @@ bool KarmStorage::parseLine(TQString line, long *time, TQString *name,
void KarmStorage::adjustFromLegacyFileFormat(Task* task)
{
- // unless the tqparent is the listView
- if ( task->tqparent() )
- task->tqparent()->changeTimes(-task->sessionTime(), -task->time());
+ // unless the parent is the listView
+ if ( task->parent() )
+ task->parent()->changeTimes(-task->sessionTime(), -task->time());
// traverse depth first -
// as soon as we're in a leaf, we'll substract it's time from the tqparent
// then, while descending back we'll do the same for each node untill
// we reach the root
for ( Task* subtask = task->firstChild(); subtask;
@@ -701,7 +701,7 @@ TQString KarmStorage::exportcsvFile( TaskView *taskview,
// public routines:
//
-TQString KarmStorage::addTask(const Task* task, const Task* tqparent)
+TQString KarmStorage::addTask(const Task* task, const Task* parent)
{
KCal::Todo* todo;
TQString uid;
@@ -710,8 +710,8 @@ TQString KarmStorage::addTask(const Task* task, const Task* tqparent)
if ( _calendar->addTodo( todo ) )
{
task->asTodo( todo );
- if (tqparent)
- todo->setRelatedTo(_calendar->todo(tqparent->uid()));
+ if (parent)
+ todo->setRelatedTo(_calendar->todo(parent->uid()));
uid = todo->uid();
}
else
@@ -156,7 +156,7 @@ TQString KarmStorage::load (TaskView* view, const Preferences* preferences, TQSt
TQDict< Task > map;
// Build dictionary to look up Task object from Todo uid. Each task is a
- // TQListViewItem, and is initially added with the view as the tqparent.
+ // TQListViewItem, and is initially added with the view as the parent.
todoList = _calendar->rawTodos();
kdDebug(5970) << "KarmStorage::load "
@@ -186,7 +186,7 @@ TQString KarmStorage::load (TaskView* view, const Preferences* preferences, TQSt
task->setPixmapProgress();
}
- // Load each task under it's tqparent task.
+ // Load each task under it's parent task.
for( todo = todoList.begin(); todo != todoList.end(); ++todo )
{
@@ -245,7 +245,7 @@ TQString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
// 1. insert tasks form rc into taskview
// 1.1. Build dictionary to look up Task object from Todo uid. Each task is a
- // TQListViewItem, and is initially added with the view as the tqparent.
+ // TQListViewItem, and is initially added with the view as the parent.
todoList = rc->rawTodos();
for( todo = todoList.begin(); todo != todoList.end(); ++todo )
@@ -255,7 +255,7 @@ TQString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
task->setPixmapProgress();
}
- // 1.1. Load each task under it's tqparent task.
+ // 1.1. Load each task under it's parent task.
for( todo = todoList.begin(); todo != todoList.end(); ++todo )
{
@@ -556,12 +556,12 @@ bool KarmStorage::parseLine(TQString line, long *time, TQString *name,
// traverse depth first -
- // as soon as we're in a leaf, we'll substract it's time from the tqparent
+ // as soon as we're in a leaf, we'll substract it's time from the parent
// then, while descending back we'll do the same for each node untill
// we reach the root